define(
//begin v1.x content
({
	"findLabel": "חיפוש: ",
	"findTooltip": "ציינו תמליל לחיפוש",
	"replaceLabel": "החלפה עם: ",
	"replaceTooltip": "ציינו תמליל להחלפה",
	"findReplace": "חיפוש והחלפה ",
	"matchCase": "התאמת רישיות ",
	"matchCaseTooltip": "התאמת רישיות",
	"backwards": "אחורה ",
	"backwardsTooltip": "חיפוש תמליל אחורה ",
	"replaceAllButton": "החלפת הכל ",
	"replaceAllButtonTooltip": "החלפת כל התמליל ",
	"findButton": "חיפוש",
	"findButtonTooltip": "חיפוש התמליל",
	"replaceButton": "החלפה ",
	"replaceButtonTooltip": "החלפת התמליל",
	"replaceDialogText": "הוחלפו ${0} מופעים ",
	"eofDialogText": "המופע האחרון ${0}",
	"eofDialogTextFind": "נמצאו",
	"eofDialogTextReplace": "הוחלפו "
})

//end v1.x content
);
